.. _orm_toplevel:

SQLAlchemy ORM
==============

Here, the Object Relational Mapper is introduced and fully described. If you
want to work with higher-level SQL which is constructed automatically for you,
as well as automated persistence of Python objects, proceed first to the
tutorial.

.. toctree::
    :maxdepth: 2

    tutorial
    mapper_config
    relationships
    loading_objects
    session
    extending
    extensions/index
    examples
